charge_class

Function charge_class 

pub const fn charge_class(state: BatteryState) -> ChargeClass
The ChargeClass behind a five-way BatteryState.

One definition so every consumer of the same monitor — an on-demand read and an asynchronous notification, in particular — reports the same charge state for the same sample.